#!/bin/bash
#

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <c2[:py3]|e15|e17[:py3]> <debug|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    PRODUCTS=${product_dir}:${PRODUCTS}
    
    setup ssibuildshims ${ssibuildshims_version}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
basequal=${2}
extraqual=${3}
maketar=${4}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=dk2nudata
origpkgver=v01_08_00
pkgver=${origpkgver}d
ssibuildshims_version=v1_04_13
pkgtarname=${package}-${origpkgver}

get_this_dir

get_ssibuildshims

source define_basics --

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
   exit 0
fi

echo "building ${package} for ${OS}-${plat}-${qualdir} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

case ${extraqual} in
debug) extra_command="-DCMAKE_BUILD_TYPE=Debug";;
prof)  extra_command="-DCMAKE_BUILD_TYPE=MinSizeRel";;
* )
   echo "ERROR: please specify debug or prof"
   usage
   exit 1
;;
esac

if [[ "${basequal}" == e1[04579] ]]
then                             
  cc=gcc                         
  cxx=g++                        
elif [[ "${basequal}" == e1[04579]:py3 ]]
then                             
  cc=gcc                         
  cxx=g++                        
elif [[ "${basequal}" == c[27] ]]
then
  cc=clang
  cxx=clang++
elif [[ "${basequal}" == c[27]:py3 ]]
then
  cc=clang
  cxx=clang++
else
  ssi_die "Qualifier $basequal not recognized."
fi

echo "Building ${package} in ${blddir}"

mkdir -p ${pkgdir}
if [ ! -d ${pkgdir} ]
then
   echo "ERROR: failed to create ${pkgdir}"
   exit 1
fi
mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

setup -B ${package} ${pkgver} -q ${fullqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || ssi_die "ERROR: fake setup failed"

# We need cmake
source ${SSIBUILDSHIMS_DIR}/bin/setup_cmake || ssi_die "ERROR: failed to setup camke"

if [ -z ${DK2NU} ]
then
   echo "ERROR: failed to setup dk2nudata"
   exit 1
else
   echo "dk2nudata: ${DK2NU}"
fi

if [ -z ${ROOTSYS} ]
then
   echo "ERROR: failed to setup root"
   exit 1
else
   echo "ROOTSYS: ${ROOTSYS}"
fi

if [ -z ${LIBXML2_INC} ]
then
   echo "ERROR: failed to setup libxml"
   exit 1
else
   echo "LIBXML2_INC: ${LIBXML2_INC}"
fi

if [ -z ${ROOT_INCLUDE_PATH} ]
then
  echo "ROOT_INCLUDE_PATH is undefined"
else
  echo "ROOT_INCLUDE_PATH: ${ROOT_INCLUDE_PATH}"
fi

set -x

cd ${blddir}

# dk2nu is using root-config to determine build flags
env CC=${cc} CXX=${cxx} FC=gfortran cmake \
    -DCMAKE_INSTALL_PREFIX=${pkgdir} \
    ${extra_command} \
    -DWITH_GENIE=OFF \
    ${sourcedir}/dk2nu || ssi_die "ERROR: cmake step failed"
make VERBOSE=t all install || ssi_die "ERROR: make failed"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup -B ${package} ${pkgver} -q ${fullqual} -z ${product_dir} || ssi_die "ERROR: setup failed"
echo "${package} is installed at ${DK2NU}"

# this must be last
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
